@@ -7,7 +7,7 @@ import pyqtgraph as pg
 import numpy as np
 import os
 import pytplot
-from pyqtgraph.Qt import QtCore
+from pyqtgraph.Qt import QtCore, QtGui
 from .CustomImage.ColorbarImage import ColorbarImage
 from .CustomAxis.BlankAxis import BlankAxis
 from .CustomLegend.CustomLegend import CustomLegendItem
@@ -57,6 +57,12 @@ class TVarFigureMap(pg.GraphicsLayout):
                                str(pytplot.data_quants[self.tvar_name].attrs['plot_options']['extras']['char_size'])
                                + 'pt', 'color': '#000'}
 
+        # Set the font size of the axes
+        font = QtGui.QFont()
+        font.setPixelSize(pytplot.tplot_opt_glob['axis_font_size'])
+        self.xaxis.tickFont = font
+        self.yaxis.tickFont = font
+
         if show_xaxis:
             self.plotwindow.showAxis('bottom')
         else:
@@ -259,7 +265,10 @@ class TVarFigureMap(pg.GraphicsLayout):
         if 'line_color' in pytplot.data_quants[self.tvar_name].attrs['plot_options']['extras']:
             return pytplot.data_quants[self.tvar_name].attrs['plot_options']['extras']['line_color']
         else:
-            return pytplot.tplot_utilities.rgb_color(['k', 'r', 'seagreen', 'b', 'darkturquoise', 'm', 'goldenrod'])
+            if pytplot.tplot_opt_glob['black_background']:
+                return pytplot.tplot_utilities.rgb_color(['w', 'r', 'seagreen', 'b', 'darkturquoise', 'm', 'goldenrod'])
+            else:
+                return pytplot.tplot_utilities.rgb_color(['k', 'r', 'seagreen', 'b', 'darkturquoise', 'm', 'goldenrod'])
 
     def _setcolormap(self):
         colors = []
@@ -346,8 +355,12 @@ class TVarFigureMap(pg.GraphicsLayout):
                 self.plotwindow.addItem(bm)
 
     def _set_crosshairs(self):
-        self.vLine = pg.InfiniteLine(angle=90, movable=False, pen=pg.mkPen('k'))
-        self.hLine = pg.InfiniteLine(angle=0, movable=False, pen=pg.mkPen('k'))
+        if pytplot.tplot_opt_glob['black_background']:
+            self.vLine = pg.InfiniteLine(angle=90, movable=False, pen=pg.mkPen('w'))
+            self.hLine = pg.InfiniteLine(angle=0, movable=False, pen=pg.mkPen('w'))
+        else:
+            self.vLine = pg.InfiniteLine(angle=90, movable=False, pen=pg.mkPen('k'))
+            self.hLine = pg.InfiniteLine(angle=0, movable=False, pen=pg.mkPen('k'))
         self.plotwindow.addItem(self.vLine, ignoreBounds=True)
         self.plotwindow.addItem(self.hLine, ignoreBounds=True)
         self.vLine.setVisible(False)
